import greenfoot.World;
import greenfoot.GreenfootImage;
import greenfoot.Greenfoot;
import java.awt.Color;

/**
 * Screen
 * 
 * @author Taylor Born
 * @version July 2013
 */
public class Screen extends World
{
    private static final int WIDTH = 600;
    private static final int HEIGHT = 400;

    private final GreenfootImage IMAGE = new GreenfootImage(WIDTH, HEIGHT);
    private final int ORIGIN_X = WIDTH / 2;
    private final int ORIGIN_Y = HEIGHT * 3 / 4;
    private final Color PARABOLA_COLOR = Color.RED;
    private final Color CATENARY_COLOR = Color.GREEN;
    private final Slider PARABOLA_SLIDER = new Slider(200, 10, 500, 145, 1, PARABOLA_COLOR);
    private final Slider CATENARY_SLIDER = new Slider(200, 10, 300, 90, 1, CATENARY_COLOR);

    public Screen()
    {
        super(WIDTH, HEIGHT, 1);
        setBackground(IMAGE);
        draw();
        
        addObject(PARABOLA_SLIDER, WIDTH / 4, HEIGHT - PARABOLA_SLIDER.getGUIHeight());
        addObject(CATENARY_SLIDER, WIDTH * 3 / 4, HEIGHT - PARABOLA_SLIDER.getGUIHeight());
        
        Greenfoot.start();
    }
    public void act()
    {
        if (PARABOLA_SLIDER.hasChanged() || CATENARY_SLIDER.hasChanged())
            draw();
    }
    private void draw()
    {
        IMAGE.clear();
        IMAGE.setColor(Color.BLACK);
        IMAGE.fill();
        IMAGE.setColor(Color.WHITE);
        IMAGE.drawLine(ORIGIN_X, 0, ORIGIN_X, HEIGHT);
        IMAGE.drawLine(0, ORIGIN_Y, WIDTH, ORIGIN_Y);
        
        int catenary_Y_offset = (int)(CATENARY_SLIDER.getValue() * Math.cosh(0));
        
        for (int x = -ORIGIN_X; x < ORIGIN_X; x++)
        {
            // Draw Catenary
            plot(x, catenary_Y_offset - calculateCatenary(x), CATENARY_COLOR);
            
            // Draw Parabola
            plot(x, -calculateParabola(x), PARABOLA_COLOR);
        }
        
//         IMAGE.mirrorVertically();
    }
    private void plot(int x, int y, Color color)
    {
        y += ORIGIN_Y;
        if (y > -1 && y < HEIGHT)
            IMAGE.setColorAt(ORIGIN_X + x, y, color);
    }
    private int calculateCatenary(int x)
    {
        return (int)(CATENARY_SLIDER.getValue() * Math.cosh(x / CATENARY_SLIDER.getValue()));
    }
    private int calculateParabola(int x)
    {
        return x * x / (int)PARABOLA_SLIDER.getValue();
    }
}